Structs
- Lexer
- SQL lexer that produces a stream of tokens from source text.
- Tokenize
Duration Seconds Histogram - Histogram buckets for
fsqlite_tokenize_duration_seconds. - Tokenize
Metrics Snapshot - Point-in-time tokenize metric snapshot.
Functions
- reset_
tokenize_ metrics - Reset tokenize metrics (used by tests/diagnostics).
- set_
force_ interner_ scan_ bench - Force the O(entries)
retained_bytesfold on the current thread (bd-5310l bench A/B only). - set_
tokenize_ metrics_ enabled - Enable or disable tokenize metrics collection on the hot path.
- tokenize_
metrics_ enabled - Return whether tokenize metrics collection is enabled.
- tokenize_
metrics_ snapshot - Point-in-time snapshot of tokenize metrics.