Structs
- Parse
Error - Parse
Metrics Snapshot - Point-in-time parse metrics snapshot.
- Parser
- Statement
Parse Scratch - Caller-owned statement parse scratch.
Constants
- MAX_
PARSE_ DEPTH - Maximum expression nesting depth.
Functions
- parse_
first_ statement_ with_ tail - Parse only the first top-level SQL statement from
sqland report the byte offset immediately after the consumed statement text. - parse_
metrics_ enabled - Return whether parse metrics collection is enabled.
- parse_
metrics_ snapshot - Take a point-in-time snapshot of parse metrics.
- parse_
single_ statement_ with_ scratch - Parse exactly one statement from
sqlusing caller-owned lookaside. - parse_
statements_ with_ scratch - Parse all statements from
sqlusing caller-owned token/error lookaside. - reset_
parse_ metrics - Reset parse metrics (used by tests/diagnostics).
- set_
parse_ metrics_ enabled - Enable or disable parse metrics collection on the hot path.