Module parser

Module parser 

Structs

ParseError
ParseMetricsSnapshot
Point-in-time parse metrics snapshot.
Parser
StatementParseScratch
Caller-owned statement parse scratch.

Constants

MAX_PARSE_DEPTH
Maximum expression nesting depth.

Functions

parse_first_statement_with_tail
Parse only the first top-level SQL statement from sql and report the byte offset immediately after the consumed statement text.
parse_metrics_enabled
Return whether parse metrics collection is enabled.
parse_metrics_snapshot
Take a point-in-time snapshot of parse metrics.
parse_single_statement_with_scratch
Parse exactly one statement from sql using caller-owned lookaside.
parse_statements_with_scratch
Parse all statements from sql using caller-owned token/error lookaside.
reset_parse_metrics
Reset parse metrics (used by tests/diagnostics).
set_parse_metrics_enabled
Enable or disable parse metrics collection on the hot path.