Module parser

Module parser 

Structs

ParseError
ParseMetricsSnapshot
Point-in-time parse metrics snapshot.
Parser

Constants

MAX_PARSE_DEPTH

Functions

parse_first_statement_with_tail
Parse only the first top-level SQL statement from sql and report the byte offset immediately after the consumed statement text.
parse_metrics_enabled
Return whether parse metrics collection is enabled.
parse_metrics_snapshot
Take a point-in-time snapshot of parse metrics.
reset_parse_metrics
Reset parse metrics (used by tests/diagnostics).
set_parse_metrics_enabled
Enable or disable parse metrics collection on the hot path.