Structs
- Parse
Error - Parse
Metrics Snapshot - Point-in-time parse metrics snapshot.
- Parser
Constants
Functions
- parse_
first_ statement_ with_ tail - Parse only the first top-level SQL statement from
sqland report the byte offset immediately after the consumed statement text. - parse_
metrics_ enabled - Return whether parse metrics collection is enabled.
- parse_
metrics_ snapshot - Take a point-in-time snapshot of parse metrics.
- reset_
parse_ metrics - Reset parse metrics (used by tests/diagnostics).
- set_
parse_ metrics_ enabled - Enable or disable parse metrics collection on the hot path.